@@ -29,7 +29,10 @@ use serde::{Deserialize, Serialize};
 use sqlparser_derive::{Visit, VisitMut};
 
 use super::{display_comma_separated, Expr, Ident, Password, Spanned};
-use crate::ast::{display_separated, ObjectName};
+use crate::ast::{
+    display_separated, CascadeOption, CurrentGrantsKind, GrantObjects, Grantee, ObjectName,
+    Privileges,
+};
 use crate::tokenizer::Span;
 
 /// An option in `ROLE` statement.
@@ -39,15 +42,25 @@ use crate::tokenizer::Span;
 #[cfg_attr(feature = "serde", derive(Serialize, Deserialize))]
 #[cfg_attr(feature = "visitor", derive(Visit, VisitMut))]
 pub enum RoleOption {
+    /// Enable or disable BYPASSRLS.
     BypassRLS(bool),
+    /// Connection limit expression.
     ConnectionLimit(Expr),
+    /// CREATEDB flag.
     CreateDB(bool),
+    /// CREATEROLE flag.
     CreateRole(bool),
+    /// INHERIT flag.
     Inherit(bool),
+    /// LOGIN flag.
     Login(bool),
+    /// Password value or NULL password.
     Password(Password),
+    /// Replication privilege flag.
     Replication(bool),
+    /// SUPERUSER flag.
     SuperUser(bool),
+    /// `VALID UNTIL` expression.
     ValidUntil(Expr),
 }
 
@@ -104,8 +117,11 @@ impl fmt::Display for RoleOption {
 #[cfg_attr(feature = "serde", derive(Serialize, Deserialize))]
 #[cfg_attr(feature = "visitor", derive(Visit, VisitMut))]
 pub enum SetConfigValue {
+    /// Use the default value.
     Default,
+    /// Use the current value (`FROM CURRENT`).
     FromCurrent,
+    /// Set to the provided expression value.
     Value(Expr),
 }
 
@@ -116,7 +132,9 @@ pub enum SetConfigValue {
 #[cfg_attr(feature = "serde", derive(Serialize, Deserialize))]
 #[cfg_attr(feature = "visitor", derive(Visit, VisitMut))]
 pub enum ResetConfig {
+    /// Reset all configuration parameters.
     ALL,
+    /// Reset the named configuration parameter.
     ConfigName(ObjectName),
 }
 
@@ -127,28 +145,48 @@ pub enum ResetConfig {
 pub enum AlterRoleOperation {
     /// Generic
     RenameRole {
+        /// Role name to rename.
         role_name: Ident,
     },
     /// MS SQL Server
     /// <https://learn.microsoft.com/en-us/sql/t-sql/statements/alter-role-transact-sql>
     AddMember {
+        /// Member name to add to the role.
         member_name: Ident,
     },
+    /// MS SQL Server
+    ///
+    /// <https://learn.microsoft.com/en-us/sql/t-sql/statements/alter-role-transact-sql>
     DropMember {
+        /// Member name to remove from the role.
         member_name: Ident,
     },
     /// PostgreSQL
     /// <https://www.postgresql.org/docs/current/sql-alterrole.html>
     WithOptions {
+        /// Role options to apply.
         options: Vec<RoleOption>,
     },
+    /// PostgreSQL
+    /// <https://www.postgresql.org/docs/current/sql-alterrole.html>
+    ///
+    /// `SET configuration_parameter { TO | = } { value | DEFAULT }`
     Set {
+        /// Configuration name to set.
         config_name: ObjectName,
+        /// Value to assign to the configuration.
         config_value: SetConfigValue,
+        /// Optional database scope for the setting.
         in_database: Option<ObjectName>,
     },
+    /// PostgreSQL
+    /// <https://www.postgresql.org/docs/current/sql-alterrole.html>
+    ///
+    /// `RESET configuration_parameter` | `RESET ALL`
     Reset {
+        /// Configuration to reset.
         config_name: ResetConfig,
+        /// Optional database scope for the reset.
         in_database: Option<ObjectName>,
     },
 }
@@ -205,14 +243,22 @@ impl fmt::Display for AlterRoleOperation {
 #[cfg_attr(feature = "serde", derive(Serialize, Deserialize))]
 #[cfg_attr(feature = "visitor", derive(Visit, VisitMut))]
 pub enum Use {
-    Catalog(ObjectName),            // e.g. `USE CATALOG foo.bar`
-    Schema(ObjectName),             // e.g. `USE SCHEMA foo.bar`
-    Database(ObjectName),           // e.g. `USE DATABASE foo.bar`
-    Warehouse(ObjectName),          // e.g. `USE WAREHOUSE foo.bar`
-    Role(ObjectName),               // e.g. `USE ROLE PUBLIC`
-    SecondaryRoles(SecondaryRoles), // e.g. `USE SECONDARY ROLES ALL`
-    Object(ObjectName),             // e.g. `USE foo.bar`
-    Default,                        // e.g. `USE DEFAULT`
+    /// Switch to the given catalog (e.g. `USE CATALOG ...`).
+    Catalog(ObjectName),
+    /// Switch to the given schema (e.g. `USE SCHEMA ...`).
+    Schema(ObjectName),
+    /// Switch to the given database (e.g. `USE DATABASE ...`).
+    Database(ObjectName),
+    /// Switch to the given warehouse (e.g. `USE WAREHOUSE ...`).
+    Warehouse(ObjectName),
+    /// Switch to the given role (e.g. `USE ROLE ...`).
+    Role(ObjectName),
+    /// Use secondary roles specification (e.g. `USE SECONDARY ROLES ...`).
+    SecondaryRoles(SecondaryRoles),
+    /// Use the specified object (e.g. `USE foo.bar`).
+    Object(ObjectName),
+    /// Reset to default (e.g. `USE DEFAULT`).
+    Default,
 }
 
 impl fmt::Display for Use {
@@ -239,8 +285,11 @@ impl fmt::Display for Use {
 #[cfg_attr(feature = "serde", derive(Serialize, Deserialize))]
 #[cfg_attr(feature = "visitor", derive(Visit, VisitMut))]
 pub enum SecondaryRoles {
+    /// Use all secondary roles.
     All,
+    /// Use no secondary roles.
     None,
+    /// Explicit list of secondary roles.
     List(Vec<Ident>),
 }
 
@@ -260,25 +309,43 @@ impl fmt::Display for SecondaryRoles {
 #[cfg_attr(feature = "serde", derive(Serialize, Deserialize))]
 #[cfg_attr(feature = "visitor", derive(Visit, VisitMut))]
 pub struct CreateRole {
+    /// Role names to create.
     pub names: Vec<ObjectName>,
+    /// Whether `IF NOT EXISTS` was specified.
     pub if_not_exists: bool,
     // Postgres
+    /// Whether `LOGIN` was specified.
     pub login: Option<bool>,
+    /// Whether `INHERIT` was specified.
     pub inherit: Option<bool>,
+    /// Whether `BYPASSRLS` was specified.
     pub bypassrls: Option<bool>,
+    /// Optional password for the role.
     pub password: Option<Password>,
+    /// Whether `SUPERUSER` was specified.
     pub superuser: Option<bool>,
+    /// Whether `CREATEDB` was specified.
     pub create_db: Option<bool>,
+    /// Whether `CREATEROLE` was specified.
     pub create_role: Option<bool>,
+    /// Whether `REPLICATION` privilege was specified.
     pub replication: Option<bool>,
+    /// Optional connection limit expression.
     pub connection_limit: Option<Expr>,
+    /// Optional account validity expression.
     pub valid_until: Option<Expr>,
+    /// Members of `IN ROLE` clause.
     pub in_role: Vec<Ident>,
+    /// Members of `IN GROUP` clause.
     pub in_group: Vec<Ident>,
+    /// Roles listed in `ROLE` clause.
     pub role: Vec<Ident>,
+    /// Users listed in `USER` clause.
     pub user: Vec<Ident>,
+    /// Admin users listed in `ADMIN` clause.
     pub admin: Vec<Ident>,
     // MSSQL
+    /// Optional authorization owner.
     pub authorization_owner: Option<ObjectName>,
 }
 
@@ -363,3 +430,99 @@ impl Spanned for CreateRole {
         Span::empty()
     }
 }
+
+/// GRANT privileges ON objects TO grantees
+#[derive(Debug, Clone, PartialEq, PartialOrd, Eq, Ord, Hash)]
+#[cfg_attr(feature = "serde", derive(Serialize, Deserialize))]
+#[cfg_attr(feature = "visitor", derive(Visit, VisitMut))]
+pub struct Grant {
+    /// Privileges being granted.
+    pub privileges: Privileges,
+    /// Optional objects the privileges apply to.
+    pub objects: Option<GrantObjects>,
+    /// List of grantees receiving the privileges.
+    pub grantees: Vec<Grantee>,
+    /// Whether `WITH GRANT OPTION` is present.
+    pub with_grant_option: bool,
+    /// Optional `AS GRANTOR` identifier.
+    pub as_grantor: Option<Ident>,
+    /// Optional `GRANTED BY` identifier.
+    ///
+    /// [BigQuery](https://cloud.google.com/bigquery/docs/reference/standard-sql/dcl-statements)
+    pub granted_by: Option<Ident>,
+    /// Optional `CURRENT GRANTS` modifier.
+    ///
+    /// [Snowflake](https://docs.snowflake.com/en/sql-reference/sql/grant-privilege)
+    pub current_grants: Option<CurrentGrantsKind>,
+}
+
+impl fmt::Display for Grant {
+    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+        write!(f, "GRANT {privileges}", privileges = self.privileges)?;
+        if let Some(ref objects) = self.objects {
+            write!(f, " ON {objects}")?;
+        }
+        write!(f, " TO {}", display_comma_separated(&self.grantees))?;
+        if let Some(ref current_grants) = self.current_grants {
+            write!(f, " {current_grants}")?;
+        }
+        if self.with_grant_option {
+            write!(f, " WITH GRANT OPTION")?;
+        }
+        if let Some(ref as_grantor) = self.as_grantor {
+            write!(f, " AS {as_grantor}")?;
+        }
+        if let Some(ref granted_by) = self.granted_by {
+            write!(f, " GRANTED BY {granted_by}")?;
+        }
+        Ok(())
+    }
+}
+
+impl From<Grant> for crate::ast::Statement {
+    fn from(v: Grant) -> Self {
+        crate::ast::Statement::Grant(v)
+    }
+}
+
+/// REVOKE privileges ON objects FROM grantees
+#[derive(Debug, Clone, PartialEq, PartialOrd, Eq, Ord, Hash)]
+#[cfg_attr(feature = "serde", derive(Serialize, Deserialize))]
+#[cfg_attr(feature = "visitor", derive(Visit, VisitMut))]
+pub struct Revoke {
+    /// Privileges to revoke.
+    pub privileges: Privileges,
+    /// Optional objects from which to revoke.
+    pub objects: Option<GrantObjects>,
+    /// Grantees affected by the revoke.
+    pub grantees: Vec<Grantee>,
+    /// Optional `GRANTED BY` identifier.
+    ///
+    /// [BigQuery](https://cloud.google.com/bigquery/docs/reference/standard-sql/dcl-statements)
+    pub granted_by: Option<Ident>,
+    /// Optional `CASCADE`/`RESTRICT` behavior.
+    pub cascade: Option<CascadeOption>,
+}
+
+impl fmt::Display for Revoke {
+    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+        write!(f, "REVOKE {privileges}", privileges = self.privileges)?;
+        if let Some(ref objects) = self.objects {
+            write!(f, " ON {objects}")?;
+        }
+        write!(f, " FROM {}", display_comma_separated(&self.grantees))?;
+        if let Some(ref granted_by) = self.granted_by {
+            write!(f, " GRANTED BY {granted_by}")?;
+        }
+        if let Some(ref cascade) = self.cascade {
+            write!(f, " {cascade}")?;
+        }
+        Ok(())
+    }
+}
+
+impl From<Revoke> for crate::ast::Statement {
+    fn from(v: Revoke) -> Self {
+        crate::ast::Statement::Revoke(v)
+    }
+}
