@@ -37,6 +37,7 @@ use sqlparser_derive::{Visit, VisitMut};
 /// expands to `pub const SELECT = "SELECT";`
 macro_rules! kw_def {
     ($ident:ident = $string_keyword:expr) => {
+        #[doc = concat!("The `", $string_keyword, "` SQL keyword.")]
         pub const $ident: &'static str = $string_keyword;
     };
     ($ident:ident) => {
@@ -54,19 +55,35 @@ macro_rules! define_keywords {
         #[cfg_attr(feature = "serde", derive(Serialize, Deserialize))]
         #[cfg_attr(feature = "visitor", derive(Visit, VisitMut))]
         #[allow(non_camel_case_types)]
+        /// An enumeration of SQL keywords recognized by the parser.
         pub enum Keyword {
+            /// Represents no keyword.
             NoKeyword,
-            $($ident),*
+            $(
+                #[doc = concat!("The `", stringify!($ident), "` SQL keyword.")]
+                $ident
+            ),*
         }
 
+        /// Array of all `Keyword` enum values in declaration order.
         pub const ALL_KEYWORDS_INDEX: &[Keyword] = &[
             $(Keyword::$ident),*
         ];
 
         $(kw_def!($ident $(= $string_keyword)?);)*
+        /// Array of all SQL keywords as string constants.
         pub const ALL_KEYWORDS: &[&str] = &[
             $($ident),*
         ];
+
+        impl core::fmt::Display for Keyword {
+            fn fmt(&self, f: &mut core::fmt::Formatter) -> core::fmt::Result {
+                match self {
+                    Keyword::NoKeyword => write!(f, "NoKeyword"),
+                    $(Keyword::$ident => write!(f, "{}", $ident),)*
+                }
+            }
+        }
     };
 }
 
@@ -316,6 +333,7 @@ define_keywords!(
     DISCARD,
     DISCONNECT,
     DISTINCT,
+    DISTINCTROW,
     DISTRIBUTE,
     DIV,
     DO,
@@ -538,6 +556,7 @@ define_keywords!(
     KEY_BLOCK_SIZE,
     KILL,
     LAG,
+    LAMBDA,
     LANGUAGE,
     LARGE,
     LAST,
@@ -628,6 +647,7 @@ define_keywords!(
     MODIFIES,
     MODIFY,
     MODULE,
+    MODULUS,
     MONITOR,
     MONTH,
     MONTHS,
@@ -658,6 +678,7 @@ define_keywords!(
     NOCOMPRESS,
     NOCREATEDB,
     NOCREATEROLE,
+    NOCYCLE,
     NOINHERIT,
     NOLOGIN,
     NONE,
@@ -828,6 +849,7 @@ define_keywords!(
     RELAY,
     RELEASE,
     RELEASES,
+    REMAINDER,
     REMOTE,
     REMOVE,
     REMOVEQUOTES,
@@ -936,6 +958,11 @@ define_keywords!(
     SQLEXCEPTION,
     SQLSTATE,
     SQLWARNING,
+    SQL_BIG_RESULT,
+    SQL_BUFFER_RESULT,
+    SQL_CALC_FOUND_ROWS,
+    SQL_NO_CACHE,
+    SQL_SMALL_RESULT,
     SQRT,
     SRID,
     STABLE,
@@ -1029,6 +1056,7 @@ define_keywords!(
     TRANSLATE_REGEX,
     TRANSLATION,
     TREAT,
+    TREE,
     TRIGGER,
     TRIM,
     TRIM_ARRAY,
@@ -1238,9 +1266,9 @@ pub const RESERVED_FOR_COLUMN_ALIAS: &[Keyword] = &[
     Keyword::END,
 ];
 
-// Global list of reserved keywords allowed after FROM.
-// Parser should call Dialect::get_reserved_keyword_after_from
-// to allow for each dialect to customize the list.
+/// Global list of reserved keywords allowed after FROM.
+/// Parser should call Dialect::get_reserved_keyword_after_from
+/// to allow for each dialect to customize the list.
 pub const RESERVED_FOR_TABLE_FACTOR: &[Keyword] = &[
     Keyword::INTO,
     Keyword::LIMIT,
