@@ -73,7 +73,8 @@ fn test_databricks_exists() {
                 ),
                 Expr::Lambda(LambdaFunction {
                     params: OneOrManyWithParens::One(Ident::new("x")),
-                    body: Box::new(Expr::IsNull(Box::new(Expr::Identifier(Ident::new("x")))))
+                    body: Box::new(Expr::IsNull(Box::new(Expr::Identifier(Ident::new("x"))))),
+                    syntax: LambdaSyntax::Arrow,
                 })
             ]
         ),
@@ -141,7 +142,8 @@ fn test_databricks_lambdas() {
                             },
                         ],
                         else_result: Some(Box::new(Expr::value(number("1"))))
-                    })
+                    }),
+                    syntax: LambdaSyntax::Arrow,
                 })
             ]
         )),
@@ -347,6 +349,7 @@ fn data_type_timestamp_ntz() {
                 "created_at".into()
             )))),
             data_type: DataType::TimestampNtz(None),
+            array: false,
             format: None
         }
     );
@@ -366,3 +369,24 @@ fn data_type_timestamp_ntz() {
         s => panic!("Unexpected statement: {s:?}"),
     }
 }
+
+#[test]
+fn parse_table_time_travel() {
+    all_dialects_where(|d| d.supports_table_versioning())
+        .verified_only_select("SELECT 1 FROM t1 TIMESTAMP AS OF '2018-10-18T22:15:12.013Z'");
+
+    all_dialects_where(|d| d.supports_table_versioning()).verified_only_select(
+        "SELECT 1 FROM t1 TIMESTAMP AS OF CURRENT_TIMESTAMP() - INTERVAL 12 HOURS",
+    );
+
+    all_dialects_where(|d| d.supports_table_versioning())
+        .verified_only_select("SELECT 1 FROM t1 VERSION AS OF 1");
+
+    assert!(databricks()
+        .parse_sql_statements("SELECT 1 FROM t1 FOR TIMESTAMP AS OF 'some_timestamp'")
+        .is_err());
+
+    assert!(all_dialects_where(|d| d.supports_table_versioning())
+        .parse_sql_statements("SELECT 1 FROM t1 VERSION AS OF 1 - 2",)
+        .is_err())
+}
